@@ -3,6 +3,8 @@
 // Use is subject to license terms.
 //
 
+use std::collections::BTreeMap;
+
 use kube::ResourceExt as _;
 
 use super::*;
@@ -10,26 +12,40 @@ use super::*;
 pub use cluster_role::ClusterRoleExt;
 pub use cluster_role_binding::ClusterRoleBindingExt;
 pub use configmap::ConfigMapExt;
+pub use container::ContainerExt;
+pub use daemon_set::DaemonSetExt;
 pub use deployment::DeploymentExt;
+pub use env::EnvVarExt;
+pub use label_selector::LabelSelectorExt;
 pub use namespace::NamespaceExt;
+pub use pod_spec::PodSpecExt;
+pub use pod_template_spec::PodTemplateSpecExt;
 pub use policy_rule::PolicyRuleExt;
 pub use role::RoleExt;
 pub use role_binding::RoleBindingExt;
 pub use role_ref::RoleRefExt;
 pub use secret::SecretExt;
 pub use service_account::ServiceAccountExt;
+pub use service::ServiceExt;
 pub use subject::SubjectExt;
 
 mod cluster_role;
 mod cluster_role_binding;
 mod configmap;
+mod container;
+mod daemon_set;
 mod deployment;
+mod env;
+mod label_selector;
 mod namespace;
+mod pod_spec;
+mod pod_template_spec;
 mod policy_rule;
 mod role;
 mod role_binding;
 mod role_ref;
 mod secret;
+mod service;
 mod service_account;
 mod subject;
 
