@@ -11,6 +11,7 @@ pub trait PolicyRuleExt: Sized {
     fn api_groups(self, groups: impl IntoIterator<Item = impl ToString>) -> Self;
     fn resource(self, resource: impl ToString) -> Self;
     fn resources(self, resources: impl IntoIterator<Item = impl ToString>) -> Self;
+    fn with_status(self) -> Self;
     fn verb(self, verb: impl ToString) -> Self;
     fn verbs(self, verbs: impl IntoIterator<Item = impl ToString>) -> Self;
     fn all_resources(self) -> Self {
@@ -53,6 +54,21 @@ impl PolicyRuleExt for rbacv1::PolicyRule {
         Self { resources, ..self }
     }
 
+    fn with_status(mut self) -> Self {
+        let resources = self
+            .resources
+            .unwrap_or_default()
+            .into_iter()
+            .flat_map(|resource| [format!("{}/status", resource), resource])
+            .collect::<Vec<_>>();
+        self.resources = if resources.is_empty() {
+            None
+        } else {
+            Some(resources)
+        };
+        self
+    }
+
     fn verb(self, verb: impl ToString) -> Self {
         let verbs = vec![verb.to_string()];
         Self { verbs, ..self }
